==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/work/NPCSheepShearGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal.work;

import cc.thonly.reverie_dreams.entity.npc.NPCEntityImpl;
import cc.thonly.reverie_dreams.entity.npc.NPCState;
import cc.thonly.reverie_dreams.entity.npc.NPCStates;
import cc.thonly.reverie_dreams.entity.npc.NPCWorkModes;
import cc.thonly.reverie_dreams.interfaces.IAnimalEntity;
import lombok.Getter;
import net.minecraft.class_1268;
import net.minecraft.class_1309;
import net.minecraft.class_1405;
import net.minecraft.class_1472;
import net.minecraft.class_1799;
import net.minecraft.class_1820;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import net.minecraft.class_4051;
import net.minecraft.class_5712;
import org.jetbrains.annotations.Nullable;

import java.util.EnumSet;
import java.util.List;

@Getter
public class NPCSheepShearGoal extends class_1405 {
    private final NPCEntityImpl maid;
    private final class_4051 targetPredicate = class_4051.method_36625().method_18418(16).method_18420((e, w) -> {
        return !e.method_16914();
    });
    @Nullable
    private Runnable task;
    private class_1472 targetEntity;
    @Nullable
    private class_1799 itemStack;

    public NPCSheepShearGoal(NPCEntityImpl maid) {
        super(maid, false);
        this.maid = maid;
        this.method_6265(EnumSet.of(class_4134.field_18408));
    }

    @Override
    public boolean method_6264() {
        if (!this.maid.method_6181() || this.maid.method_24345()) {
            return false;
        }
        class_1799 stack = this.maid.method_5998(class_1268.field_5808);
        if (stack == null) {
            return false;
        }
        if (stack.method_7960()) {
            return false;
        }
        NPCState state = this.maid.getNpcState();
        class_1309 owner = this.maid.method_35057();
        if (owner == null || state != NPCStates.WORKING || this.maid.getWorkMode() != NPCWorkModes.SHEEP_SHEARING || !(stack.method_7909() instanceof class_1820)) {
            return false;
        }
        class_2338 workPos = this.maid.getWorkingPos();
        class_3218 serverWorld = method_64451(this.maid);

        List<class_1472> targets = this.field_6660.method_37908().method_8390(class_1472.class, new class_238(workPos).method_1009(16, 8, 16), (e) -> {
            boolean alive = e.method_5805();
            if (e.method_27072()) {
                return alive;
            }
            return false;
        });
        this.targetEntity = serverWorld.method_64393(targets, this.targetPredicate, this.maid, this.maid.method_23317(), this.maid.method_23320(), this.maid.method_23321());
        return this.targetEntity != null;
    }

    @Override
    public void method_6269() {
        this.task = () -> {
            if (this.itemStack == null) {
                return;
            }
            if (this.itemStack.method_7960()) {
                return;
            }
            if (!(this.itemStack.method_7909() instanceof class_1820)) {
                return;
            }
            class_3218 world = method_64451(this.targetEntity);
            this.maid.method_6104(class_1268.field_5808);
            this.targetEntity.method_6636(world, class_3419.field_15248, itemStack);
            this.targetEntity.method_32875(class_5712.field_28730, this.targetEntity);
            this.itemStack.method_71012(1, this.targetEntity, class_1268.field_5808);
        };
    }

    @Override
    public void method_6268() {
        this.itemStack = this.maid.method_5998(class_1268.field_5808);
        if (this.task == null) {
            return;
        }
        if (this.targetEntity != null && this.targetEntity.method_5805()) {
            this.maid.method_5942().method_6335(this.targetEntity, 1.0D);

            if (this.maid.method_5858(this.targetEntity) <= 2.0D) {
                this.task.run();
                this.task = null;
                this.method_6270();
            }
        }
    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/work/NPCSheepShearGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal.work;

import cc.thonly.reverie_dreams.entity.npc.BaseNPCLikeEntity;
import cc.thonly.reverie_dreams.data.npc.NPCState;
import cc.thonly.reverie_dreams.registry.content.NPCStates;
import cc.thonly.reverie_dreams.registry.content.NPCWorkModes;
import lombok.Getter;
import net.minecraft.class_1268;
import net.minecraft.class_1309;
import net.minecraft.class_1405;
import net.minecraft.class_1472;
import net.minecraft.class_1799;
import net.minecraft.class_1820;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import net.minecraft.class_4051;
import net.minecraft.class_5712;
import org.jetbrains.annotations.Nullable;

import java.util.EnumSet;
import java.util.List;

@Getter
public class NPCSheepShearGoal extends class_1405 {
    private final BaseNPCLikeEntity maid;
    private final class_4051 targetPredicate = class_4051.method_36625().method_18418(16).method_18420((e, w) -> {
        return !e.method_16914();
    });
    @Nullable
    private Runnable task;
    private class_1472 targetEntity;
    @Nullable
    private class_1799 itemStack;

    public NPCSheepShearGoal(BaseNPCLikeEntity maid) {
        super(maid, false);
        this.maid = maid;
        this.method_6265(EnumSet.of(class_4134.field_18408));
    }

    @Override
    public boolean method_6264() {
        if (!this.maid.method_6181() || this.maid.method_24345()) {
            return false;
        }
        class_1799 stack = this.maid.method_5998(class_1268.field_5808);
        if (stack == null) {
            return false;
        }
        if (stack.method_7960()) {
            return false;
        }
        NPCState state = this.maid.getNpcState();
        class_1309 owner = this.maid.method_35057();
        if (owner == null || state != NPCStates.WORKING || this.maid.getWorkMode() != NPCWorkModes.SHEEP_SHEARING || !(stack.method_7909() instanceof class_1820)) {
            return false;
        }
        class_2338 workPos = this.maid.getWorkingPos();
        class_3218 serverWorld = method_64451(this.maid);

        List<class_1472> targets = this.field_6660.method_37908().method_8390(class_1472.class, new class_238(workPos).method_1009(16, 8, 16), (e) -> {
            boolean alive = e.method_5805();
            if (e.method_27072()) {
                return alive;
            }
            return false;
        });
        this.targetEntity = serverWorld.method_64393(targets, this.targetPredicate, this.maid, this.maid.method_23317(), this.maid.method_23320(), this.maid.method_23321());
        return this.targetEntity != null;
    }

    @Override
    public void method_6269() {
        this.task = () -> {
            if (this.itemStack == null) {
                return;
            }
            if (this.itemStack.method_7960()) {
                return;
            }
            if (!(this.itemStack.method_7909() instanceof class_1820)) {
                return;
            }
            class_3218 world = method_64451(this.targetEntity);
            this.maid.method_6104(class_1268.field_5808);
            this.targetEntity.method_6636(world, class_3419.field_15248, itemStack);
            this.targetEntity.method_32875(class_5712.field_28730, this.targetEntity);
            this.itemStack.method_71012(1, this.targetEntity, class_1268.field_5808);
        };
    }

    @Override
    public void method_6268() {
        this.itemStack = this.maid.method_5998(class_1268.field_5808);
        if (this.task == null) {
            return;
        }
        if (this.targetEntity != null && this.targetEntity.method_5805()) {
            this.maid.method_5942().method_6335(this.targetEntity, 1.0D);

            if (this.maid.method_5858(this.targetEntity) <= 2.0D) {
                this.task.run();
                this.task = null;
                this.method_6270();
            }
        }
    }

}
